import router from './router'
import { isRelogin } from '@/config/axios/service'
import { getAccessToken } from '@/utils/auth'
import { useTitle } from '@/hooks/web/useTitle'
import { useNProgress } from '@/hooks/web/useNProgress'
import { usePageLoading } from '@/hooks/web/usePageLoading'
import { useDictStoreWithOut } from '@/store/modules/dict'
import { useUserStoreWithOut } from '@/store/modules/user'
import { usePermissionStoreWithOut } from '@/store/modules/permission'
import { useAppStoreWithOut } from '@/store/modules/app'
import { getTenantId, getAppId, setTenantId, setAppId } from '@/utils/auth'

const { start, done } = useNProgress()

const { loadStart, loadDone } = usePageLoading()
// 路由不重定向白名单
const whiteList = ['/login', '/social-login', '/auth-redirect', '/bind', '/register', '/swagger']

// 路由加载前
router.beforeEach(async (to, from, next) => {
  start()
  loadStart()
  const userStore = useUserStoreWithOut()
  if (to.path == '/login') {
    userStore.resetState() // 重置用户信息状态
  }
  if (getAccessToken()) {
    if (to.path === '/login') {
      if (to.query?.tenantId && to.query?.appId) {
        setApp(to.query.tenantId, to.query.appId)
        await waitTime(1500)
      }
      next({ path: '/' })
    } else {
      // 获取所有字典
      const dictStore = useDictStoreWithOut()
      const permissionStore = usePermissionStoreWithOut()
      if (!dictStore.getIsSetDict) {
        await dictStore.setDictMap()
      }
      if (!userStore.getIsSetUser) {
        isRelogin.show = true
        await userStore.setUserInfoAction()
        isRelogin.show = false
        // 后端过滤菜单
        await permissionStore.generateRoutes()
        permissionStore.getAddRouters.forEach((route) => {
          router.addRoute(route) // 动态添加可访问路由表
        })
        const redirectPath = from.query.redirect || to.path
        const redirect = decodeURIComponent(redirectPath)
        const nextData = to.path === redirect ? { ...to, replace: true } : { path: redirect }
        next(nextData)
      } else {
        next()
      }
    }
  } else {
    if (whiteList.indexOf(to.path) !== -1) {
      next()
    } else {
      const tenantId = getTenantId()
      const appId = getAppId()
      if (tenantId && appId) {
        next(`/login?tenantId=${tenantId}&appId=${appId}&redirect=${to.fullPath}`) // 否则全部重定向到登录页
      } else {
        // next(`/login?redirect=${to.fullPath}`)
        // 否则全部重定向到平台登陆页
        window.location.href = 'https://cloud.ahduima.com/ss/login'
      }
    }
  }
})

async function waitTime(seconds) {
  return new Promise((resolve) => {
    setTimeout(() => {
      resolve()
    }, seconds)
  })
}

function setApp(tenantId, appId) {
  setTenantId(tenantId)

  setAppId(appId)
  const appStore = useAppStoreWithOut()
  appStore.setAppInfo(appId)
}

router.afterEach((to) => {
  useTitle(to?.meta?.title)
  done() // 结束Progress
  loadDone()
})
